@@ -1,8 +1,8 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-
 import Scene from './scene';
 import Snap from './snap';
+import * as SharedStyle from '../../shared-style';
 
 export default function State(_ref) {
   var state = _ref.state,
@@ -23,7 +23,7 @@ export default function State(_ref) {
   return React.createElement(
     'g',
     null,
-    React.createElement('rect', { x: '0', y: '0', width: width, height: height, fill: '#fff' }),
+    React.createElement('rect', { x: '0', y: '0', width: width, height: height, fill: SharedStyle.COLORS.white }),
     React.createElement(
       'g',
       { transform: 'translate(0, ' + scene.height + ') scale(1, -1)' },
