@@ -43,5 +43,12 @@ export default {
   "Lines": "Linee",
   "Holes": "Buchi",
   "Items": "Oggetti",
-  "Areas": "Aree"
+  "Areas": "Aree",
+  "Snap to Point": "Snap al Punto",
+  "Snap to Line": "Snap alla Linea",
+  "Snap to Segment": "Snap al Segmento",
+  "Snap to Grid": "Snap alla Griglia",
+  "Mouse X Coordinate": "Coordinata X del Mouse",
+  "Mouse Y Coordinate": "Coordinata Y del Mouse",
+  "Scene Zoom Level": "Livello di Zoom della Scena"
 };
\ No newline at end of file
