@@ -3,13 +3,19 @@ import * as GraphInnerCycles from './graph-inner-cycles';
 import * as MathUtils from './math';
 import * as SnapUtils from './snap';
 import * as SnapSceneUtils from './snap-scene';
+import * as history from './history';
+import * as IDBroker from './id-broker';
+import * as LayerOperations from './layer-operations';
 
-export { GeometryUtils, GraphInnerCycles, MathUtils, SnapUtils, SnapSceneUtils };
+export { GeometryUtils, GraphInnerCycles, MathUtils, SnapUtils, SnapSceneUtils, history, IDBroker, LayerOperations };
 
 export default {
   GeometryUtils: GeometryUtils,
   GraphInnerCycles: GraphInnerCycles,
   MathUtils: MathUtils,
   SnapUtils: SnapUtils,
-  SnapSceneUtils: SnapSceneUtils
+  SnapSceneUtils: SnapSceneUtils,
+  history: history,
+  IDBroker: IDBroker,
+  LayerOperations: LayerOperations
 };
\ No newline at end of file
