@@ -4,17 +4,15 @@ import {
   END_DRAGGING_VERTEX,
   MODE_DRAGGING_VERTEX,
   MODE_IDLE
-} from '../constants'
-import {Map, List} from 'immutable';
-import {sceneSnapElements} from '../utils/snap-scene';
-import {nearestSnap} from '../utils/snap';
+} from '../constants';
+import { Map, List } from 'immutable';
 import {
-  detectAndUpdateAreas,
-  removeLine,
-  addLineAvoidingIntersections,
-  mergeEqualsVertices
-} from '../utils/layer-operations';
-import {orderVertices, pointsDistance} from "../utils/geometry";
+  LayerOperations,
+  SnapSceneUtils,
+  SnapUtils,
+  GeometryUtils,
+  history
+} from '../utils/export';
 
 export default function (state, action) {
   switch (action.type) {
@@ -34,7 +32,7 @@ export default function (state, action) {
 
 function beginDraggingVertex(state, layerID, vertexID, x, y) {
 
-  let snapElements = sceneSnapElements(state.scene, new List(), state.snapMask);
+  let snapElements = SnapSceneUtils.sceneSnapElements(state.scene, new List(), state.snapMask);
 
   return state.merge({
     mode: MODE_DRAGGING_VERTEX,
@@ -46,26 +44,26 @@ function beginDraggingVertex(state, layerID, vertexID, x, y) {
 }
 
 function updateDraggingVertex(state, x, y) {
-  let {draggingSupport, snapElements, scene} = state;
+  let { draggingSupport, snapElements, scene } = state;
 
   let snap = null;
   if (state.snapMask && !state.snapMask.isEmpty()) {
-    snap = nearestSnap(snapElements, x, y, state.snapMask);
-    if (snap) ({x, y} = snap.point);
+    snap = SnapUtils.nearestSnap(snapElements, x, y, state.snapMask);
+    if (snap) ({ x, y } = snap.point);
   }
 
   let layerID = draggingSupport.get('layerID');
   let vertexID = draggingSupport.get('vertexID');
   return state.merge({
     activeSnapElement: snap ? snap.snap : null,
-    scene: scene.mergeIn(['layers', layerID, 'vertices', vertexID], {x, y})
+    scene: scene.mergeIn(['layers', layerID, 'vertices', vertexID], { x, y })
   });
 }
 
 function endDraggingVertex(state, x, y) {
   let catalog = state.catalog;
 
-  let {draggingSupport} = state;
+  let { draggingSupport } = state;
   let layerID = draggingSupport.get('layerID');
   let vertexID = draggingSupport.get('vertexID');
   let lineIDs = state.scene.layers.get(layerID).vertices.get(vertexID).lines;
@@ -91,11 +89,11 @@ function endDraggingVertex(state, x, y) {
 
         let oldHoles = [];
 
-        let orderedVertices = orderVertices([oldVertex, vertex]);
+        let orderedVertices = GeometryUtils.orderVertices([oldVertex, vertex]);
 
         line.holes.forEach(holeID => {
           let hole = layer.holes.get(holeID);
-          let oldLineLength = pointsDistance(oldVertex.x, oldVertex.y, vertex.x, vertex.y);
+          let oldLineLength = GeometryUtils.pointsDistance(oldVertex.x, oldVertex.y, vertex.x, vertex.y);
 
           let alpha = Math.atan2(orderedVertices[1].y - orderedVertices[0].y,
             orderedVertices[1].x - orderedVertices[0].x);
@@ -110,19 +108,23 @@ function endDraggingVertex(state, x, y) {
           let xp = oldLineLength * offset * Math.cos(alpha) + orderedVertices[0].x;
           let yp = oldLineLength * offset * Math.sin(alpha) + orderedVertices[0].y;
 
-          oldHoles.push({hole, offsetPosition: {x: xp, y: yp}});
+          oldHoles.push({ hole, offsetPosition: { x: xp, y: yp } });
         });
 
-        removeLine(layer, lineID);
-        addLineAvoidingIntersections(layer, line.type,
-          oldVertex.x, oldVertex.y,
-          vertex.x, vertex.y,
-          catalog,
-          line.properties, oldHoles);
+        LayerOperations.mergeEqualsVertices(layer, vertexID);
+        LayerOperations.removeLine(layer, lineID);
+
+        if (!GeometryUtils.samePoints(oldVertex, vertex)) {
+          LayerOperations.addLineAvoidingIntersections(layer, line.type,
+            oldVertex.x, oldVertex.y,
+            vertex.x, vertex.y,
+            catalog,
+            line.properties, oldHoles);
+        }
       }
     });
 
-    detectAndUpdateAreas(layer, catalog);
+    LayerOperations.detectAndUpdateAreas(layer, catalog);
   }));
 
   return state.merge({
@@ -132,6 +134,6 @@ function endDraggingVertex(state, x, y) {
 
     activeSnapElement: null,
     snapElements: new List(),
-    sceneHistory: state.sceneHistory.push(scene)
+    sceneHistory: history.historyPush(state.sceneHistory, scene)
   });
 }
